mangadap.util package
=====================

Submodules
----------

.. toctree::
   :maxdepth: 4

   mangadap.util.bitmask
   mangadap.util.constants
   mangadap.util.covariance
   mangadap.util.dapbitmask
   mangadap.util.datatable
   mangadap.util.drpbitmask
   mangadap.util.extinction
   mangadap.util.fileio
   mangadap.util.filter
   mangadap.util.fitsutil
   mangadap.util.geometry
   mangadap.util.lineprofiles
   mangadap.util.log
   mangadap.util.mapping
   mangadap.util.misc
   mangadap.util.modeling
   mangadap.util.parser
   mangadap.util.pixelmask
   mangadap.util.pkg
   mangadap.util.resolution
   mangadap.util.sampling
   mangadap.util.trace
   mangadap.util.vander

Module contents
---------------

.. automodule:: mangadap.util
   :members:
   :private-members:
   :undoc-members:
   :show-inheritance:
